@@ -1,7 +1,5 @@
 """
-Type annotations for secretsmanager service client paginators.
-
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/paginators.html)
+Main interface for secretsmanager service client paginators.
 
 Usage::
 
@@ -34,7 +32,7 @@ __all__ = ("ListSecretsPaginator",)
 
 class ListSecretsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/paginators.html#listsecretspaginator)
+    [Paginator.ListSecrets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
     """
 
     def paginate(
@@ -44,6 +42,5 @@ class ListSecretsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListSecretsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets.paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/paginators.html#listsecretspaginator)
+        [ListSecrets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets.paginate)
         """
