@@ -13,10 +13,8 @@ import sys
 from datetime import datetime
 from typing import IO, Dict, List, Union
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_secretsmanager.literals import FilterNameStringType, StatusType
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -60,7 +58,7 @@ ReplicationStatusTypeTypeDef = TypedDict(
     {
         "Region": str,
         "KmsKeyId": str,
-        "Status": Literal["InSync", "Failed", "InProgress"],
+        "Status": StatusType,
         "StatusMessage": str,
         "LastAccessedDate": datetime,
     },
@@ -159,12 +157,7 @@ DescribeSecretResponseTypeDef = TypedDict(
 )
 
 FilterTypeDef = TypedDict(
-    "FilterTypeDef",
-    {
-        "Key": Literal["description", "name", "tag-key", "tag-value", "primary-region", "all"],
-        "Values": List[str],
-    },
-    total=False,
+    "FilterTypeDef", {"Key": FilterNameStringType, "Values": List[str]}, total=False
 )
 
 GetRandomPasswordResponseTypeDef = TypedDict(
